@@ -908,7 +908,8 @@ class Line(
     @classmethod
     def post_move(cls, lines):
         Move = Pool().get('account.move')
-        Move.post(list({l.move for l in lines if l.move}))
+        Move.post(list({l.move for l in lines
+                    if l.move and l.move.state != 'posted'}))
 
     @classmethod
     def delete_move(cls, lines):
@@ -1067,7 +1068,7 @@ class Origin(origin_mixin(_states, _depends), ModelSQL, ModelView):
 
         super(Origin, cls).__register__(module_name)
 
-    @fields.depends('statement')
+    @fields.depends('statement', '_parent_statement.id')
     def on_change_with_statement_id(self, name=None):
         if self.statement:
             return self.statement.id
